"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeContainer = makeContainer;
exports.makeContainerMaxWidths = makeContainerMaxWidths;
exports.makeGutters = makeGutters;
exports.makeRow = makeRow;
exports.makeColReady = makeColReady;
exports.makeCol = makeCol;
exports.makeColOffset = makeColOffset;
exports.makeColPush = makeColPush;
exports.makeColPull = makeColPull;
exports.makeColModifier = makeColModifier;
exports.default = exports.defaultProps = void 0;

var _unitUtils = _interopRequireDefault(require("@bootstrap-styled/utils/lib/unitUtils"));

var _breakpoints = require("./breakpoints");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultProps = {
  '$grid-gutter-widths': {
    xs: '30px',
    sm: '30px',
    md: '30px',
    lg: '30px',
    xl: '30px'
  },
  '$container-max-widths': {
    sm: '540px',
    md: '720px',
    lg: '960px',
    xl: '1140px'
  },
  '$grid-breakpoints': {
    xs: '0',
    sm: '576px',
    md: '768px',
    lg: '992px',
    xl: '1200px'
  },
  '$grid-columns': 12,
  '$enable-grid-classes': true
}; // Grid system
//
// Generate semantic grid columns with these mixins.

exports.defaultProps = defaultProps;

function makeContainer() {
  var enableGridClasses = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-grid-classes'];
  var gridGutterWidths = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-gutter-widths'];

  if (enableGridClasses) {
    var columns = [];
    Object.keys(gridGutterWidths).forEach(function (breakpoint) {
      var gutter = gridGutterWidths[breakpoint];
      var column = (0, _breakpoints.mediaBreakpointUp)(breakpoint, gutter, "\n        padding-right: ".concat(_unitUtils.default.rmUnit(gutter) / 2).concat(_unitUtils.default.detectUnit(gutter), ";\n        padding-left:  ").concat(_unitUtils.default.rmUnit(gutter) / 2).concat(_unitUtils.default.detectUnit(gutter), ";\n      "));
      columns.push(column);
    });
    return "\n      position: relative;\n      margin-left: auto;\n      margin-right: auto;    \n      ".concat(columns.join('\n'), "\n    ");
  }

  return '';
} // For each breakpoint, define the maximum width of the container in a media query


function makeContainerMaxWidths() {
  var enableGridClasses = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-grid-classes'];
  var containerMaxWidths = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$container-max-widths'];
  var gridBreakpoints = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : defaultProps['$grid-breakpoints'];

  if (enableGridClasses) {
    var maximumWidthList = [];
    Object.keys(containerMaxWidths).forEach(function (breakpoint) {
      var maximumWidth = (0, _breakpoints.mediaBreakpointUp)(breakpoint, gridBreakpoints, "\n        width: ".concat(containerMaxWidths[breakpoint], ";\n        max-width: 100%;\n      "));
      maximumWidthList.push(maximumWidth);
    });
    return "\n      ".concat(maximumWidthList.join('\n'), "\n    ");
  }

  return '';
}

function makeGutters() {
  var gridGutterWidths = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$grid-gutter-widths'];
  var breakpoints = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-breakpoints'];
  var gutterList = [];
  Object.keys(gridGutterWidths).forEach(function (breakpoint) {
    var gutterValue = gridGutterWidths[breakpoint];
    gutterValue = "".concat(_unitUtils.default.rmUnit(gutterValue) / 2).concat(_unitUtils.default.detectUnit(gutterValue));
    var gutter = (0, _breakpoints.mediaBreakpointUp)(breakpoint, breakpoints, "\n      padding-right: ".concat(gutterValue, ";\n      padding-left:  ").concat(gutterValue, ";\n    "));
    gutterList.push(gutter);
  });
  return "\n    ".concat(gutterList.join('\n'), "\n  ");
}

function makeRow() {
  var enableGridClasses = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$enable-grid-classes'];
  var gridGutterWidths = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-gutter-widths'];

  if (enableGridClasses) {
    var rowList = [];
    Object.keys(gridGutterWidths).forEach(function (breakpoint) {
      var gutter = gridGutterWidths[breakpoint];
      gutter = "".concat(_unitUtils.default.rmUnit(gutter) / -2).concat(_unitUtils.default.detectUnit(gutter));
      var row = "\n        margin-right: ".concat(gutter, ";\n        margin-left:  ").concat(gutter, ";\n      ");
      rowList.push(row);
    });
    return "\n      display: flex;\n      flex-wrap: wrap;\n      ".concat(rowList.join('\n'), "\n    ");
  }

  return '';
}

function makeColReady() {
  var gridGutterWidths = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultProps['$grid-gutter-widths'];
  var colReadyList = [];
  Object.keys(gridGutterWidths).forEach(function (breakpoint) {
    var gutter = gridGutterWidths[breakpoint];
    gutter = "".concat(_unitUtils.default.rmUnit(gutter) / 2).concat(_unitUtils.default.detectUnit(gutter));
    var colReady = (0, _breakpoints.mediaBreakpointUp)(breakpoint, gridGutterWidths, "\n      padding-right: ".concat(gutter, ";\n      padding-left:  ").concat(gutter, ";\n    "));
    colReadyList.push(colReady);
  });
  return "\n    position: relative;\n    /* Prevent columns from becoming too narrow when at smaller grid tiers by */\n    /* always setting 'width: 100%;'. This works because we use 'flex' values */\n    /* later on to override this initial width. */\n    min-height: 1px; /* Prevent collapsing */\n    width: 100%;\n    ".concat(colReadyList.join('\n'), "\n  ");
}

function makeCol(size) {
  var columns = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-columns'];
  return "\n    flex: 0 0 ".concat(_unitUtils.default.toPercent(size, columns), ";\n    /* Add a 'max-width' to ensure content within each column does not blow out */\n    /* the width of the column. Applies to IE10+ and Firefox. Chrome and Safari */\n    /* do not appear to require this. */\n    max-width: ").concat(_unitUtils.default.toPercent(size, columns), ";\n  ");
}

function makeColOffset($size) {
  var columns = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-columns'];
  return "\n    margin-left: ".concat(_unitUtils.default.toPercent($size, columns), ";\n  ");
}

function makeColPush(size) {
  var columns = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-columns'];
  return "\n    left: ".concat(size > 0 ? _unitUtils.default.toPercent(size, columns) : 'auto', ";\n  ");
}

function makeColPull(size) {
  var columns = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultProps['$grid-columns'];
  return "\n    right: ".concat(size > 0 ? _unitUtils.default.toPercent(size, columns) : 'auto', ";\n  ");
}

function makeColModifier(type, size, columns) {
  var TYPE = {
    PUSH: 'push',
    PULL: 'pull',
    OFFSET: 'offset'
  };
  var modifier = '';

  if (type === TYPE.PUSH) {
    modifier = makeColPush(size, columns);
  } else if (type === TYPE.PULL) {
    modifier = makeColPull(size, columns);
  } else if (type === TYPE.OFFSET) {
    modifier = makeColOffset(size, columns);
  }

  return "\n    ".concat(modifier, "\n  ");
}

var _default = {
  defaultProps: defaultProps,
  makeContainer: makeContainer,
  makeContainerMaxWidths: makeContainerMaxWidths,
  makeGutters: makeGutters,
  makeRow: makeRow,
  makeColReady: makeColReady,
  makeCol: makeCol,
  makeColOffset: makeColOffset,
  makeColPush: makeColPush,
  makeColPull: makeColPull,
  makeColModifier: makeColModifier
};
exports.default = _default;